@@ -1,4 +1,4 @@
-package resources
+package resources_test
 
 import (
 	"testing"
